@@ -331,8 +331,6 @@ def print_result(stdscr,result,language,stats): # prints the performance result
     stdscr.clear()
     today = str(date.today())
     wpm_key = str(wpm)
-    # if wpm % 2 == 0:
-    #     wpm_key = str(wpm+1)
 
     if today not in stats:
         stats[today]={wpm_key:minutes}
@@ -668,10 +666,12 @@ def termtyper(stdscr,language,stats):
             else:
                 a=space_locations[l][j-1]+1
             if textlist[l][a:b] != ip_text: 
+                word_got_wrong = True
                 for k in range(a,b):
                     color_dict[(l,k)]=curses.color_pair(RED)
                     abs_color_dict[cum_line_lengths[l-1]+k] = color_dict[(l,k)]
 
+
             ip_text = ""
             ip_text_ix = 0
             if word_got_wrong:
@@ -1183,7 +1183,7 @@ def keyboard(stdscr,kbd_y_offset,kbd_x_offset,key_map):
 
 # Main
 
-VERSION_NUMBER = '2.0.1'
+VERSION_NUMBER = '2.0.2'
 
 def latest_version(pkg_name='termtyper'):
     url = f"https://pypi.org/pypi/{pkg_name}/json"
